@@ -7,10 +7,10 @@ from .structures.layers import Layer, AmorphousLayer, UnitCell
 from .structures.structure import Structure
 from .simulations.simulation import Simulation
 from .simulations.heat import Heat
-from .simulations.phonons import Phonon, PhononNum
+from .simulations.phonons import Phonon, PhononNum, PhononAna
 from .simulations.magnetization import Magnetization
 from .simulations.xrays import Xray, XrayKin, XrayDyn, XrayDynMag
 
 __all__ = ['Atom', 'AtomMixed', 'Layer', 'AmorphousLayer', 'UnitCell', 'Structure',
-           'Simulation', 'Heat', 'Phonon', 'PhononNum', 'Magnetization', 'Xray',
-           'XrayKin', 'XrayDyn', 'XrayDynMag', 'u', 'Q_']
+           'Simulation', 'Heat', 'Phonon', 'PhononNum', 'PhononAna', 'Magnetization',
+           'Xray', 'XrayKin', 'XrayDyn', 'XrayDynMag', 'u', 'Q_']
