@@ -99,7 +99,7 @@ class Structure:
             class_str += tab_str + 'no substrate\n'
         return class_str
 
-    def visualize(self, unit='nm', fig_size=[20, 1]):
+    def visualize(self, unit='nm', fig_size=[20, 1], cmap='Set1', linewidth=0.1, show=True):
         """visualize
 
         Simple visualization of the structure.
@@ -109,6 +109,9 @@ class Structure:
                 'nm'.
             fig_size (list[float]): figure size of the visualization plot.
                 Defaults to [20, 1].
+            cmap (str): Matplotlib colormap for colors of layers.
+            linewidth (float): line width of the patches.
+            show (boolean): show visualization plot at the end.
 
         """
         import matplotlib.pyplot as plt
@@ -124,7 +127,7 @@ class Structure:
 
         colortable = {}
         for i in range(N):
-            colortable[layer_ids[i]] = cm.get_cmap('Set1')(i)
+            colortable[layer_ids[i]] = cm.get_cmap(cmap)(i)
 
         plt.figure(figsize=fig_size)
         ax = plt.axes()
@@ -132,20 +135,25 @@ class Structure:
         for i, name in enumerate(self.get_layer_vectors()[1]):
             col = colortable.get(name, 'k')
             rect = patches.Rectangle((layer_interfaces[i], 0), np.diff(layer_interfaces)[i], 1,
-                                     linewidth=0.25, facecolor=col, edgecolor='k')
+                                     linewidth=linewidth, facecolor=col, edgecolor='k')
             ax.add_patch(rect)
 
         plt.xlim(0, thickness)
         plt.ylim(0, 1)
-        plt.xlabel('distance [{:s}]'.format(unit))
+        plt.xlabel('Distance [{:s}]'.format(unit))
         plt.yticks([], [])
 
         # add labels for legend
         for layer_id, col in colortable.items():
             plt.plot(0, 0, color=col, label=layer_id)
 
-        plt.legend(bbox_to_anchor=(0., 1.08, 1, .102), frameon=False, ncol=8)
-        plt.show()
+        leg = plt.legend(bbox_to_anchor=(0., 1.08, 1, .102), frameon=False, ncol=8)
+
+        for line in leg.get_lines():
+            line.set_linewidth(8.0)
+
+        if show:
+            plt.show()
 
     def get_hash(self, **kwargs):
         """get_hash
@@ -252,13 +260,13 @@ class Structure:
 
         """
         L = 0
-        # traverse the substructres
+        # traverse the substructures
         for i in range(len(self.sub_structures)):
             if isinstance(self.sub_structures[i][0], AmorphousLayer) or \
                     isinstance(self.sub_structures[i][0], UnitCell):
                 L = L + self.sub_structures[i][1]
             else:
-                # its a sturcture, so call the method recursively
+                # its a structure, so call the method recursively
                 L = L + self.sub_structures[i][0].get_number_of_layers() \
                     * self.sub_structures[i][1]
 
@@ -282,7 +290,7 @@ class Structure:
                 Defaults to True.
 
         Returns:
-            thickness (float, Quantitiy): the thickness from surface to bottom
+            thickness (float, Quantity): the thickness from surface to bottom
             of the structure.
 
         """
@@ -350,7 +358,7 @@ class Structure:
 
         Returns three lists with the numeric index of all layers
         in a structure given by the get_unique_layers() method and
-        addidionally vectors with the ids and Handles of the
+        additionally vectors with the ids and Handles of the
         corresponding layer instances.
         The list and order of the unique layers can be either handed
         as an input parameter or is requested at the beginning.
